{#def data #}
{% if data %}
<dl class='detail-subfields'>
    {% for location in data %}
    {{location.geoLocationPlace}}: {{location.geoLocationPoint.pointLongitude}}, {{location.geoLocationPoint.pointLatitude}}
    {% endfor %}
</dl>
{% endif %}